@@ -23,7 +23,7 @@ import octobot.enums
 
 PROJECT_NAME = "OctoBot"
 AUTHOR = "DrakkarSoftware"
-SHORT_VERSION = "0.4.16"  # major.minor.revision
+SHORT_VERSION = "0.4.21"  # major.minor.revision
 PATCH_VERSION = ""  # patch : pX
 VERSION_DEV_PHASE = ""  # alpha : a / beta : b / release candidate : rc
 VERSION_PHASE = ""  # XX
@@ -91,12 +91,19 @@ CONFIG_COMMUNITY = "community"
 CONFIG_COMMUNITY_TOKEN = "token"
 CONFIG_COMMUNITY_BOT_ID = "bot_id"
 CONFIG_COMMUNITY_ENVIRONMENT = "environment"
-USE_BETA_EARLY_ACCESS = os_util.parse_boolean_environment_var("USE_BETA_EARLY_ACCESS", "False")
-USER_ACCOUNT_EMAIL = os.getenv("USER_ACCOUNT_EMAIL", None)
-IS_CLOUD_ENV = os_util.parse_boolean_environment_var("IS_CLOUD_ENV", "False")
+USE_BETA_EARLY_ACCESS = os_util.parse_boolean_environment_var("USE_BETA_EARLY_ACCESS", "false")
+USER_ACCOUNT_EMAIL = os.getenv("USER_ACCOUNT_EMAIL", "")
+COMMUNITY_BOT_ID = os.getenv("COMMUNITY_BOT_ID", "")
+IS_CLOUD_ENV = os_util.parse_boolean_environment_var("IS_CLOUD_ENV", "false")
+CAN_INSTALL_TENTACLES = os_util.parse_boolean_environment_var("CAN_INSTALL_TENTACLES", str(not IS_CLOUD_ENV))
 
 OCTOBOT_BINARY_PROJECT_NAME = "OctoBot-Binary"
 
+# limits
+UNLIMITED_ALLOWED = -1
+MAX_ALLOWED_EXCHANGES = int(os.getenv("MAX_ALLOWED_EXCHANGES", str(UNLIMITED_ALLOWED)))
+MAX_ALLOWED_SYMBOLS = int(os.getenv("MAX_ALLOWED_SYMBOLS", str(UNLIMITED_ALLOWED)))
+
 # tentacles
 ENV_TENTACLES_URL = "TENTACLES_URL"
 ENV_COMPILED_TENTACLES_URL = "COMPILED_TENTACLES_URL"
@@ -163,7 +170,7 @@ OPTIMIZATION_CAMPAIGN_KEY = "optimization_campaign"
 
 # Databases
 DEFAULT_MAX_TOTAL_RUN_DATABASES_SIZE = 1000000000   # 1GB
-ENABLE_RUN_DATABASE_LIMIT = os_util.parse_boolean_environment_var("EXIT_BEFORE_TENTACLES_AUTO_REINSTALL", "True")
+ENABLE_RUN_DATABASE_LIMIT = os_util.parse_boolean_environment_var("ENABLE_RUN_DATABASE_LIMIT", "True")
 MAX_TOTAL_RUN_DATABASES_SIZE = int(os.getenv("MAX_TOTAL_RUN_DATABASES_SIZE", DEFAULT_MAX_TOTAL_RUN_DATABASES_SIZE))
 
 # Channel
